#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-auth
version:              1.6.11.3
visibility:           public
id:                   yesod-auth-1.6.11.3-GS0dBMcmoLYHGBVB1TUR75
key:                  yesod-auth-1.6.11.3-GS0dBMcmoLYHGBVB1TUR75
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>

category:             Web, Yesod
abi:                  4619c503aba0f58498ca32fb808d5672
exposed:              True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore

hidden-modules:       Yesod.Auth.Routes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-auth
hs-libraries:         HSyesod-auth-1.6.11.3-GS0dBMcmoLYHGBVB1TUR75
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    attoparsec-aeson-2.2.2.0-57Ahc1UJZboK3lInrrCGeb
    authenticate-1.3.5.2-C6bAevfzzAZJwPtWuyrseI base-4.18.2.1
    base16-bytestring-1.0.2.0-CMK3GBSBriI6YLNV9leCtM
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h binary-0.8.9.1
    blaze-builder-0.4.4.1-3ZGNeeLUhPeI237uQ0tBgU
    blaze-html-0.9.2.0-75IodrcvTCz887zmB9GdF1
    blaze-markup-0.8.3.0-7nU54c8JlEV3R8rkhdxvSV bytestring-0.11.5.3
    conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq
    conduit-extra-1.3.8-8C1YMRPmMt82mJiP8UVrWz containers-0.6.7
    cryptonite-0.30-K2RP6l7MNbc1iRxw92DkbX
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    email-validate-2.3.2.21-jcU1Pw2nu1AGeq5wOwxp6
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    http-client-0.7.19-4FCJ2m94wUmJsssaVohngD
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-conduit-2.3.9.1-KDnV8VsG74SBT5pJfJbgZK
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    nonce-1.0.7-Cmm6h3KqJxy7LTkftCqukD
    persistent-2.14.6.1-CXYeTUPLnecB49WmzMNtSU
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    shakespeare-2.2.0-A7a3ny4Zor96v3NfYEsb8D template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    wai-3.2.5-H9aJt8uWBWE1hbliPLgYgy
    yesod-core-1.6.28.0-6uKwjyrdZvj9FwdYKhoTuU
    yesod-form-1.7.9.3-Dcab4UAoFmhIEsTrhoJouf
    yesod-persistent-1.6.0.8-Ao9TsiR94Mx3MeOz2UdggW

haddock-interfaces:   /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html:         /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

